@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
Politeknik Alkon Kalimantan merupakan salah satu perguruan tinggi swasta yang ada di Kota Balikpapan dan berada di bawah naungan Yayasan PPSDM ALKON Kalimantan.Dulunya, Politeknik Alkon Kalimantan adalah Akademi Bahasa Asing Balikpapan yang berdiri sejak tahun 2000 dengan program studi pertama yaitu Program Diploma III Bahasa Inggris.Berdasarkan Keputusan Menteri Pendidikan, Kebudayaan, Riset, dan Teknologi Nomor 114/D/O/2024, pada tanggal 1 April 2024, Akademi Bahasa Asing Balikpapan resmi berubah bentuk menjadi Politeknik Alkon Kalimantan. Dalam perubahan ini, ditambahkan dua program studi: D-IV Keselamatan dan Kesehatan Kerja dan D-IV Manajemen Pemasaran Internasional. Politeknik Alkon Kalimantan juga terakreditasi BAIK berdasarkan SK BAN-PT Nomor: 2746/SK/BAN-PT/Ak-PNB/PT/IX/2025.

</p>

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
