<!DOCTYPE html>
<html lang="id">

<head>
     <meta charset="utf-8">
    <meta name="description"
        content="Politeknik Alkon Kalimantan adalah pilihan terbaik untuk kuliah vokasi di Balikpapan. Menyediakan program D3 Bahasa Inggris, D4 Manajemen Pemasaran Internasional, dan D4 Kesehatan dan Keselamatan Kerja dengan biaya terjangkau dan fasilitas lengkap untuk mendukung pendidikan berkualitas." />
    <meta name="keywords"
        content="Politeknik Alkon Kalimantan, kuliah vokasi Balikpapan, D3 Bahasa Inggris, D4 Manajemen Pemasaran Internasional, D4 Kesehatan dan Keselamatan Kerja,
        kuliah murah Balikpapan, kuliah karyawan, kuliah jarak jauh, biaya kuliah Politeknik Alkon, kampus Balikpapan, pendidikan vokasi Kalimantan,
        politeknik terbaik Kalimantan Timur, pendaftaran Politeknik Alkon, kampus kompetitif Politeknik Alkon, edunitas, kuliah berkualitas Kalimantan,
        politeknik unggulan Balikpapan" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title><?php echo $__env->yieldContent('title'); ?> &mdash; POLITEKNIK ALKON KALIMANTAN(Kelas Karyawan)</title>
    <meta property="og:title" content="Politeknik Alkon Kalimantan">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://poltekalkon.info/">
    <meta property="og:image" content="https://poltekalkon.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200">
    <meta property="og:image:height" content="630">
    <meta property="og:description"
        content="Politeknik Alkon Kalimantan menyediakan pendidikan vokasi unggul dengan program D3 dan D4. Biaya terjangkau, lokasi strategis di Balikpapan, dan dosen profesional menjadikan kampus ini pilihan ideal untuk masa depan gemilang." />
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@poltekalkon">
    <meta name="twitter:site" content="@poltekalkon">
    <meta name="twitter:title" content="Politeknik Alkon Kalimantan">
    <meta name="twitter:description"
        content="Kuliah di Politeknik Alkon Kalimantan: Program D3 dan D4 dengan biaya terjangkau dan fasilitas modern. Cocok untuk mahasiswa yang ingin pendidikan vokasi berkualitas di Balikpapan." />
    <meta name="twitter:domain" content="https://poltekalkon.info/">
    <meta name="twitter:image:src" content="https://poltekalkon.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Ijo-IjoTua/resources/views/auth/app.blade.php ENDPATH**/ ?>